#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.2.2
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		https://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_module_dir %(pkg-config --variable=modlibexecdir libpulse)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXfixes-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 16.1
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-gui-common-devel >= 4.1.0
BuildRequires:	qubes-db-devel
BuildRequires:	xen-devel
BuildRequires: mesa-libgbm-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	libXfixes
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
# qubesdb-read --wait option
Requires:	qubes-db >= 4.1.4
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Requires:   xorg-x11-server-Xephyr
Requires:   setxkbmap
Requires:   xsetroot
Requires:   xrdb
Requires:   xmodmap
Requires:   xev
Requires:   xdpyinfo
Requires:   xprop
Requires:   xrandr

Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

Requires: (%{name}-selinux if selinux-policy)

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
# Needed so that systemd can manage PulseAudio
Conflicts:	qubes-core-agent < 4.2.5
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%package -n qubes-gui-vnc
Summary: Remote GuiVM support using VNC
Requires: x11vnc

%description -n qubes-gui-vnc
Remote GuiVM support using VNC

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make appvm

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full} \
                     ENABLE_SELINUX=%{with selinux}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

# simplified version of preset_units() from core-agent-linux
preset_units() {
    local represet=
    cat "$1" | while read action unit_name
    do
        if [ "$action" = "#" -a "$unit_name" = "Units below this line will be re-preset on package upgrade" ]
        then
            represet=1
            continue
        fi
        echo "$action $unit_name" | grep -q '^[[:space:]]*[^#;]' || continue
        [ -n "$action" -a -n "$unit_name" ] || continue
        if [ "$2" = "initial" -o "$represet" = "1" ]
        then
            systemctl --no-reload --global preset "$unit_name" >/dev/null 2>&1 || :
        fi
    done
}

if [ $1 -eq 1 ]
then
    preset_units /usr/lib/systemd/user-preset/75-pulseaudio-qubes.preset initial
else
    preset_units /usr/lib/systemd/user-preset/75-pulseaudio-qubes.preset upgrade
fi

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-run-xephyr
/usr/bin/qubes-start-xephyr
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%{_libdir}/libxf86-qubes-common.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/X11/xinit/xinitrc.d/50guivm-windows-prefix.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
/etc/qubes-rpc/qubes.GuiVMSession
/etc/qubes/post-install.d/20-qubes-guivm-gui-agent.sh
%config /etc/sysconfig/desktop
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
/usr/lib/qubes/qubes-gui-agent-pre.sh
/usr/lib/qubes/qubes-keymap.sh
/usr/lib/qubes/qubes-xorg-wrapper
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
/etc/xdg/autostart/qubes-qrexec-fork-server.desktop
/etc/xdg/autostart/qubes-keymap.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{pa_module_dir}/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop
/usr/lib/systemd/user-preset/75-pulseaudio-qubes.preset
/usr/lib/systemd/user/pulseaudio.service.d/30_qubes.conf

%files xfce
/etc/X11/xinit/xinitrc.d/60xfce-desktop.sh

%files -n qubes-gui-vnc
#/lib/systemd/system/qubes-gui-vncserver.service
%attr(0644,root,root) /etc/X11/xorg-qubes-x11vnc.conf.template
%attr(0644,root,root) /etc/systemd/system/lightdm.service.d/qubes-guivm-vnc.conf
/usr/bin/qubes-run-x11vnc

%changelog
* Mon Jan 09 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux.git

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d79f82c
- version 4.2.2

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c188b4d
- rpm: remove explicit dependency on libvchan

* Fri Dec 30 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - efa09d0
- version 4.2.1

* Fri Dec 30 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e29d0f7
- ci: drop R4.1

* Thu Dec 29 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ef5ec2
- version 4.2.0

* Wed Dec 28 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d325ddb
- Add gui-agent-vm spec to .qubesbuilder too

* Wed Dec 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1ee1ac3
- Makefile improvements

* Wed Dec 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 8dc8d0d
- Move SELinux to a new spec file

* Wed Dec 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 792b01a
- Require pam_selinux and pam_loginuid if they exist

* Wed Dec 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 98f898d
- SELinux support

* Wed Dec 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5effd4b
- Let systemd manage PulseAudio

* Fri Dec 23 2022 Mateusz Piórkowski <mati7337@protonmail.ch> - b863e45
- Announce support for the clipboard wipe service

* Fri Dec 23 2022 Mateusz Piórkowski <mati7337@protonmail.ch> - f9cafb2
- Change the clipboard wipe service name to `gui-agent-clipboard-wipe`

* Mon Dec 05 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 92e19b4
- version 4.1.28

* Mon Dec 05 2022 Mateusz Piórkowski <mati7337@protonmail.ch> - 7b6aefa
- Make clipboard wipe togglable

* Fri Dec 02 2022 Mateusz Piórkowski <mati7337@protonmail.ch> - b87a649
- Add automatic clipboard wipe

* Thu Oct 20 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c0f9683
- version 4.1.27

* Mon Oct 17 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c8168cc
- Remove hanging person image

* Sun Oct 16 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f739fb3
- Fix pulseaudio module path

* Tue Oct 04 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 62609b5
- rpm: fix pulseaudio version detection

* Wed Jul 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a15de47
- Use larger vchan buffers

* Fri Jul 15 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 31a05ff
- Drop obsolete checks for disposable VM restore

* Wed Jun 22 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 02a62e0
- version 4.1.26

* Wed Jun 22 2022 fepitre-bot <fepitre-bot@qubes-os.org> - 1078a72
- Add pulseaudio-16.1 headers

* Wed Jun 22 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 62a661c
- get-latest-pulsecore.sh: ensure to use gpg for git tag

* Mon Jun 20 2022 ejose19 <8742215+ejose19@users.noreply.github.com> - 86e1bbe
- Adjust pulseaudio modules dir

* Mon Jun 20 2022 ejose19 <8742215+ejose19@users.noreply.github.com> - 2499ddf
- adjust pulsecore download script to use upstream repo to obtain headers

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 914db74
- .qubesbuilder: replace 'spec' by 'build'

* Mon Apr 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e04ccb1
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 399dc7a
- Drop Travis CI

* Sat Mar 05 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5a6ce85
- version 4.1.25

* Fri Mar 04 2022 Rudd-O <rudd-o@rudd-o.com> - d9f648f
- Update qubes-session

* Wed Feb 23 2022 Rudd-O <rudd-o@rudd-o.com> - ac4b08b
- Make qubes-session inherit the systemd user session variables.

* Fri Feb 18 2022 Ivan Kardykov <kardykov@tabit.pro> - c5b764b
- dummyqbs: fix debian build with glamor

* Fri Feb 18 2022 Ivan Kardykov <kardykov@tabit.pro> - dc7abce
- dummyqbs: Add glamor acceleration

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e7fa684
- version 4.1.24

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0fa4e24
- archlinux: bump xorg ABI version requirements

* Mon Dec 13 2021 Otto Sabart <seberm@seberm.com> - 4fca698
- archlinux: add lsb-release into make dependencies

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7caf286
- version 4.1.23

* Thu Oct 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - d6d74fc
- Fix minor problems

* Thu Oct 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 1cd3b7b
- Ensure that no subwindows are created

* Tue Sep 28 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ca265a
- Fix XEMBED_EMBEDDED_NOTIFY parameters

* Tue Aug 24 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 33cf99d
- version 4.1.22

* Sun Aug 01 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 63c9de3
- pulse: set module version to the PA version

* Thu Jul 29 2021 fepitre-bot <fepitre-bot@qubes-os.org> - 5da31c7
- Add pulseaudio-15.0 headers

* Sat Jul 10 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43978ae
- version 4.1.21

* Sat Jul 10 2021 Nedyalko Andreev <n@andreev.sh> - 35ae44f
- Fix support for non-latin variants when we append the us layout

* Fri Jul 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1ce1437
- version 4.1.20

* Thu Jul 08 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 4fafcb0
- Fix the name of WM_DELETE_WINDOW

* Wed Jul 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 59ddfd3
- Fix getting all the required atoms

